# pirt

This is the root of the package PIRT.

- pirt.apps: small apps related to deformations. Serve as nice examples,
  and can also be used for user interaction.
- pirt.interp: the code related to interpolation, agnostic about deformations.
- pirt.splinegrid: implements B-spline grids.
- pirt.deform: classes to work with deformations.
- pirt.reg: the registration algorithms.
